@@ -4,7 +4,7 @@ Main interface for ds service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_ds import (
         Client,
         DescribeDirectoriesPaginator,
@@ -19,10 +19,8 @@ Usage::
         ListTagsForResourcePaginator,
     )
 
-    session = boto3.Session()
-
-    client: DirectoryServiceClient = boto3.client("ds")
-    session_client: DirectoryServiceClient = session.client("ds")
+    session = Session()
+    client: DirectoryServiceClient = session.client("ds")
 
     describe_directories_paginator: DescribeDirectoriesPaginator = client.get_paginator("describe_directories")
     describe_domain_controllers_paginator: DescribeDomainControllersPaginator = client.get_paginator("describe_domain_controllers")
