@@ -161,10 +161,12 @@ ServiceName = Literal[
     "amp",
     "amplify",
     "amplifybackend",
+    "amplifyuibuilder",
     "apigateway",
     "apigatewaymanagementapi",
     "apigatewayv2",
     "appconfig",
+    "appconfigdata",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -179,6 +181,7 @@ ServiceName = Literal[
     "autoscaling",
     "autoscaling-plans",
     "backup",
+    "backup-gateway",
     "batch",
     "braket",
     "budgets",
@@ -233,6 +236,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "drs",
     "ds",
     "dynamodb",
     "dynamodbstreams",
@@ -254,6 +258,7 @@ ServiceName = Literal[
     "emr-containers",
     "es",
     "events",
+    "evidently",
     "finspace",
     "finspace-data",
     "firehose",
@@ -280,6 +285,7 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector2",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -293,6 +299,7 @@ ServiceName = Literal[
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
+    "iottwinmaker",
     "iotwireless",
     "ivs",
     "kafka",
@@ -338,7 +345,9 @@ ServiceName = Literal[
     "meteringmarketplace",
     "mgh",
     "mgn",
+    "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhubstrategy",
     "mobile",
     "mq",
     "mturk",
@@ -367,11 +376,13 @@ ServiceName = Literal[
     "qldb-session",
     "quicksight",
     "ram",
+    "rbin",
     "rds",
     "rds-data",
     "redshift",
     "redshift-data",
     "rekognition",
+    "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -381,6 +392,7 @@ ServiceName = Literal[
     "route53-recovery-readiness",
     "route53domains",
     "route53resolver",
+    "rum",
     "s3",
     "s3control",
     "s3outposts",
@@ -438,6 +450,7 @@ ServiceName = Literal[
     "workmail",
     "workmailmessageflow",
     "workspaces",
+    "workspaces-web",
     "xray",
 ]
 PaginatorName = Literal[
